==> rehype-codemirror-1.0.0.tgz: package/index.js <==
const visit = require('unist-util-visit')
const nodeToString = require('hast-util-to-string')
const CodeMirror = require('codemirror/addon/runmode/runmode.node')
require('codemirror/mode/meta')

const toLanguage = c => c.match(/language-(\w+)$/)[1]

module.exports = function rehypeCodemirror () {
  return tree => {
    visit(tree, 'element', function visitor (node, index, parent) {
      if (parent && node.tagName === 'code') {
        // Extract the name of the language from the language-${language} class
        // on the <code> element.
        const language = node.properties.className.map(toLanguage)[0]
        if (language) {
          // If the mode hasn't been loaded into CodeMirror, log it by
          // require-ing it.
          if (!CodeMirror.modes[language]) {
            if (language === 'elixir') {
              const registerMode = require('codemirror-mode-elixir/dist/module')
              registerMode.default(CodeMirror)
              CodeMirror.modeInfo.push({
                name: 'Elixir',
                mime: 'text/x-elixir',
                mode: 'elixir',
                ext: ['ex', 'exs']
              })
            } else {
              require(`codemirror/mode/${language}/${language}`)
            }
          }

          // Extract the CodeMirror language mode mime type.
          const { mime } = CodeMirror.findModeByName(language)
          if (mime) {
            // Convert the HAST node to a string.
            const code = nodeToString(node)

            const children = []
            let lastStyle
            let tokenString = ''
            function addChild (token, style) {
              const child = { type: 'text', value: token }
              if (style) {
                return children.push({
                  type: 'element',
                  tagName: 'span',
                  properties: { className: [style] },
                  children: [child]
                })
              }
              children.push(child)
            }

            // Run the CodeMirror mode against the code string in order to
            // create the span elements needed to add the appropriate classes
            // needed to syntax highlight the different parts of the code.
            CodeMirror.runMode(code, mime, (token, style) => {
              if (lastStyle === style) {
                tokenString += token
              } else {
                if (tokenString) {
                  addChild(tokenString, lastStyle)
                }
                tokenString = token
              }
              lastStyle = style
            })
            addChild(tokenString, lastStyle)

            // Add all the new styled elements to the <code> element node.
            node.children = children
          } else {
            // TODO: add debug
          }
        }
      }
    })
  }
}

==> rehype-codemirror-1.0.1.tgz: package/index.js <==
const visit = require('unist-util-visit')
const nodeToString = require('hast-util-to-string')
const CodeMirror = require('codemirror/addon/runmode/runmode.node')
require('codemirror/mode/meta')

const toLanguage = c => {
  const matches = c.match(/language-(\w+)$/)
  return matches ? matches[1] : undefined
}

module.exports = function rehypeCodemirror () {
  return tree => {
    visit(tree, 'element', function visitor (node, index, parent) {
      if (parent && node.tagName === 'code') {
        // Extract the name of the language from the language-${language} class
        // on the <code> element.
        const language = node.properties.className.map(toLanguage)[0]
        if (language) {
          // If the mode hasn't been loaded into CodeMirror, log it by
          // require-ing it.
          if (!CodeMirror.modes[language]) {
            if (language === 'elixir') {
              // TODO: uncomment next release
              // const registerMode = require('codemirror-mode-elixir/dist/module')
              // registerMode.default(CodeMirror)
              // CodeMirror.modeInfo.push({
              //   name: 'Elixir',
              //   mime: 'text/x-elixir',
              //   mode: 'elixir',
              //   ext: ['ex', 'exs']
              // })
              return
            } else {
              require(`codemirror/mode/${language}/${language}`)
            }
          }

          // Extract the CodeMirror language mode mime type.
          const { mime } = CodeMirror.findModeByName(language)
          if (mime) {
            // Convert the HAST node to a string.
            const code = nodeToString(node)

            const children = []
            let lastStyle
            let tokenString = ''
            function addChild (token, style) {
              const child = { type: 'text', value: token }
              if (style) {
                return children.push({
                  type: 'element',
                  tagName: 'span',
                  properties: { className: [style] },
                  children: [child]
                })
              }
              children.push(child)
            }

            // Run the CodeMirror mode against the code string in order to
            // create the span elements needed to add the appropriate classes
            // needed to syntax highlight the different parts of the code.
            CodeMirror.runMode(code, mime, (token, style) => {
              if (lastStyle === style) {
                tokenString += token
              } else {
                if (tokenString) {
                  addChild(tokenString, lastStyle)
                }
                tokenString = token
              }
              lastStyle = style
            })
            addChild(tokenString, lastStyle)

            // Add all the new styled elements to the <code> element node.
            node.children = children
          } else {
            // TODO: add debug
          }
        }
      }
    })
  }
}
